rai\_toolbox.augmentations.fourier.FourierBasis
===============================================

.. currentmodule:: rai_toolbox.augmentations.fourier

.. autoclass:: FourierBasis

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~FourierBasis.__init__

   